from setuptools import setup, find_packages


VERSION = "0.0.0"


def read_requirements():
    """
    Read requirements from requirements.txt file.
    """
    with open("requirements.txt", encoding="UTF-8") as file:
        return list(file)


def get_long_description():
    """
    Read README.md file.
    """
    with open("README.md", encoding="utf8") as file:
        return file.read()


setup(
    name="brag",
    description="A CLI tool for maintaining and rendering a career brag document, automating file organization, and tracking accomplishments.",
    long_description=get_long_description(),
    long_description_content_type="text/markdown",
    author="Sébastien De Revière",
    url="https://github.com/sderev/brag",
    project_urls={
        "Documentation": "https://github.com/sderev/brag",
        "Issues": "http://github.com/sderev/brag/issues",
        "Changelog": "https://github.com/sderev/brag/releases",
    },
    license="Apache Licence, Version 2.0",
    version=VERSION,
    packages=find_packages(),
    install_requires=read_requirements(),
    entry_points={
        "console_scripts": [
        ]
    },
    python_requires=">=3.11",
)
